local electuaries = ...

local myMonument = {
    DataType = "BUILDING",
    Id = "ELECTUARIES_BUILDING",
    Name = "ELECTUARIES_NAME",
    Description = "ELECTUARIES_DESC",
    BuildingType = "GENERAL"
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    electuaries:log("Hello World: version 1.5")
    myMonument.BuildingPartSetList = {
		{
			Name = "ELECTUARIES_PARTSETLIST_NAME",
	                BuildingPartList = { "ELECTUARIES_PART" }
                }
        } 
    ElectuariesTagBehaviorWork = "WORK_BEHAVIOR"
    _CoreBuildingZone = { Polygon = polygon.createRectangle( {4, 6} ) } 
else
    electuaries:log("Hello World: version " .. foundation.getGameVersion())
    myMonument.AssetCoreBuildingPart = "ELECTUARIES_PART"
    ElectuariesTagBehaviorWork = "BEHAVIOR_WORK"

    if version.cmp(foundation.getGameVersion(), "1.6.6") < 0 then
        electuaries:log("Hello World: version 1.6.5")
        _CoreBuildingZone = { Polygon = polygon.createRectangle( {4, 6} ) } 
    else
        electuaries:log("Hello World: version 1.6.6")
        _CoreBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 6} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
   end
end

electuaries:register(myMonument)
 
-- Apply building asset processor
electuaries:registerAssetProcessor("models/Home5.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

electuaries:registerAssetId("models/Home5.fbx/Prefab/homePart", "ELECTUARIES_PREFAB")

electuaries:register({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = "ELECTUARIES_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = "ELECTUARIES_FUNCTION_LIST"
})

electuaries:register({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = "ELECTUARIES_FUNCTION_LIST"
})

function registerReceipts(_receiptsNumber, _receiptsList )
    electuaries:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = "ELECTUARIES_RECEIPTS_" .. _receiptsNumber .. "_FUNCTION",
                Name = "ELECTUARIES_RECEIPTS_" .. _receiptsNumber .. "_FUNCTION_NAME",
                TypeList = { "LUXURY_FOOD" },
                IsOverrideCapacity = true,
                CapacityPerSlot = 50,
		WorkerCapacity = 1,
                RelatedJob = { Job = ApothecaryPrefix, Behavior = ElectuariesTagBehaviorWork },
                ResourceProduced = {
			{ Resource = ElectuaryPrefix, Quantity = 1 }
                }
    })

    for i, resourceItem in ipairs(_receiptsList) do
        electuaries:override({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = "ELECTUARIES_RECEIPTS_" .. _receiptsNumber .. "_FUNCTION",
                InputInventoryCapacity = { 
                            Action = "APPEND",
			    { Resource = resourceItem, Quantity = 50 }
                },
                ResourceListNeeded = {
                            Action = "APPEND",
			    { Resource = resourceItem, Quantity = 1 }
                }
        })
    end

    electuaries:override({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = "ELECTUARIES_FUNCTION_LIST",
                AssetFunctionList = {
                        Action = "APPEND",
                        "ELECTUARIES_RECEIPTS_" .. _receiptsNumber .. "_FUNCTION"
                }
    })
end


registerReceipts( "1", { "BERRIES", "HONEY" } )
registerReceipts( "2", { "BERRIES", SugarPrefix } )
registerReceipts( "3", { "HERBS", "HONEY" } )
registerReceipts( "4", { "HERBS", SugarPrefix } )

electuaries:register({
--Dclare que l'objet que l'on cre appartient  la class BUILDING_PART
	DataType = "BUILDING_PART",
--Cr l'objet
	Id = "ELECTUARIES_PART",
	Description = "Faut bien a!",
        BuildingZone = _CoreBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
--on dclare d'aller chercher ELECTUARIES_PREFAB pour construire l'object final ( c'est dans le Fbx )
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "ELECTUARIES_PREFAB"
	},
--Les ressources ncessaires.
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 20 },
			{ Resource = "STONE", Quantity = 10 }
		}
	},
        VillagerCapacity = 1,
  	AssetBuildingFunction = "ELECTUARIES_ASSIGNABLE_FUNCTION"
})

electuaries:registerPrefabComponent("models/Home5.fbx/Prefab/homePart", {
	DataType = "COMP_DIRT_RECTANGLE",
	Size = {4, 6}
})

-- Override building part components properties (generated by the building asset processor) to add building zones
electuaries:registerPrefabComponent("models/Home5.fbx/Prefab/homePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 4, 6 }
})

electuaries:registerAssetId("models/Home5.fbx/Prefab/homePart/step_2/cheminee/SmokeEmitter", "ELECTUARIES_SMOKE_EMITTER_PREFAB")

electuaries:registerPrefabComponent("models/Home5.fbx/Prefab/homePart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
                 { "ELECTUARIES_SMOKE_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
})

-- Register air vent particle system
electuaries:registerPrefabComponent("models/Home5.fbx/Prefab/homePart/step_2/cheminee/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_HOUSING_SMOKE",
	IsPlaying = true,
	IsEmitting = true
})

electuaries:registerPrefabComponent("models/Home5.fbx/Prefab/homePart/step_2/cheminee/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

